Module load
sequent_
repl
0.3.0
Module load
Module Items
Structs
In sequent_
repl::
commands
sequent_repl
::
commands
Module
load
Loading of a simulation from a YAML document.
Structs

Load
Command that will load the simulation from a user-specified YAML file. Upon completion, the simulation will be reset to the initial state, as per the loaded file, and the cursor position reset to 0.
Parser
Parser for
Load
.